<?php
namespace Teknisa\CUS\Modules\Relatorio\Controllers;

use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DataSource\FilterCriteria;
use Zeedhi\Framework\Report\ReportService;
use Teknisa\GER\Utilities\Util;

class Cus00900 extends \Zeedhi\Framework\Controller\Report {

    protected $util;
    protected $qr2Strategy;
    protected $crudService;
    protected $dataSourceManager;

    public function __construct(ReportService $reportService, Util $util, $qr2Strategy, $crudService, $dataSourceManager) {
        $this->util          = $util;
        $this->qr2Strategy   = $qr2Strategy;
        $this->reportService = $reportService;
        $this->crudService   = $crudService;
        $this->dataSourceManager = $dataSourceManager;
    }

    protected $reportMapping = array (
        'cus00900' =>
        array (
            'strategy' => 'QR2',
            'parameterMapping' =>
            array (
              'NMTIPOCUSTO'   => 'P_NMCUSTO',
              'CDTIPOCUSTO'   => 'P_NRTIPOCUSTO',
              'CDTIPORECE'    => 'P_TIPORECE',
              'CDFILIAL'      => 'P_CDFILIAL',
              'ORDENA'        => 'P_ORDENA',
              'CDSERVFILI'    => 'P_CDSERVFILI',
              'CDPRATOINI'    => 'P_CDPRATOINI',
              'CDFILICUSTO'   => 'P_CDFILICUSTO',
              'CDNVPRATO'     => 'P_CDNVPRATO',
              'CDPRATOFIM'    => 'P_CDPRATOFIM',
              'P_NRTAMCODIGO' => 'P_NRTAMCODIGO',
              'DTCUSTO'       => 'P_DTCUSTO',
              'NRTAMACNIVEL'  => 'P_NRTAMACNIVEL',
              'TAMCODIGO'     => 'P_TAMCODIGO',
            ),
        ),
        'cus00901' =>
        array (
            'strategy' => 'QR2',
            'parameterMapping' =>
            array (
              'CDTIPOCUSTO'   => 'P_NRTIPOCUSTO',
              'CDFILICUSTO'   => 'P_CDFILICUSTO',
              'CDNVPRATO'     => 'P_CDNVPRATO',
              'P_NRTAMCODIGO' => 'P_NRTAMCODIGO',
              'DTCUSTO'       => 'P_DTCUSTO',
              'ORDENA'        => 'P_ORDENA',
              'CDSERVFILI'    => 'P_CDSERVFILI',
              'CDTIPORECE'    => 'P_TIPORECE',
              'CDPRATOINI'    => 'P_CDPRATOINI',
              'CDPRATOFIM'    => 'P_CDPRATOFIM',
              'CDFILIAL'      => 'P_CDFILIAL',
              'NRTAMACNIVEL'  => 'P_NRTAMACNIVEL',
              'NMTIPOCUSTO'   => 'P_NMCUSTO',
              'TAMCODIGO'     => 'P_TAMCODIGO',
            ),
        ),
    );
  
    public function beforeProcessReport(DTO\Request\Row $request, DTO\Response $response) {
        $row = $request->getRow();
        $this->qr2Strategy->setQr2Type($row['QR2TYPE']);
        $row["CDFILIAL"]   = $row['CDTIPORECE'] == "P" ? "XXXX" : join("_", $row["NMFILIAL"]);
        
        if($row['CDTIPORECE'] != "P" && $row['ALLNMFILIAL'] == 'T') {
            $row["CDFILIAL"] = $this->getFiliais($row);
        }
        
        $row["CDSERVFILI"] = $row['CDTIPORECE'] == "P" ? "XXX"  : join("_", $row["NMSERVICO"]);
        
        if($row['CDTIPORECE'] == "S" && $row['ALLSERVFILI'] == "T") {
            $row["CDSERVFILI"] = "T";
        }

        $row["CDFILCENTPME"] = "";
        $row["NMFILCENTPME"] = "";
        $row["CDTIPOCARD"]   = "";
        $row["NMTIPOCARD"]   = "";
        $row["IDTIPOCARD"]   = "N";
        $row["CDPRATOFIM"]   = str_pad($row["CDPRATOFIM"], 10, 'z');
        //cast para inteiro
        $row["ORDENA"]+=0;
    }
    
	private function getFiliais($row) {
		$filiais = array();
		$conditions = array(
			array(
        	    'columnName' => "CDGRUPFILI",
        	    'operator' => '=',
        	    'value' => $row['CDGRUPFILI'] == '' ? 'T' : $row['CDGRUPFILI']
        	),
        	array(
        	    'columnName' => "CDOPERADOR",
        	    'operator' => '=',
        	    'value' => $this->crudService->getEnvironment()->getCdOperador()
        	),
        	array(
        	    'columnName' => "NRORG",
        	    'operator' => '=',
        	    'value' => $this->crudService->getEnvironment()->getNrOrg()
        	)
        );
        $filterCriteria = new FilterCriteria('filial_operador_grupfili', $conditions);
		$filterCriteria = $this->crudService->populateParameterBag($filterCriteria, array("CDGRUPFILI", "CDOPERADOR", "NRORG"));
		$dataSetFiliais = $this->dataSourceManager->findBy($filterCriteria)->getRows();
		foreach ($dataSetFiliais as $filial) {
			array_push($filiais, $filial['CDFILIAL']);
		}
		return join("_", $filiais);
	}

}